Coverage for jacc/apps.py: 100%

# Coverage for jacc/apps.py : 100%

## 5 statements 5 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from django.apps import AppConfig

2 from django.utils.translation import gettext_lazy as _

3

4

5 class JaccConfig(AppConfig):

6 name = 'jacc'

7 verbose_name = _('Accounting')